==> vulcanjs-cli-3.0.9.tgz: package/src/generator-vulcanjs/generators/component/index.js <==
const VulcanGenerator = require('../../lib/VulcanGenerator');
const ast = require('../../lib/ast');

module.exports = class extends VulcanGenerator {
  initializing () {
    this._assert('isVulcan');
    this._assert('hasNonZeroPackages');
  }

  _registerArguments () {
    this._registerOptions(
      'packageName',
      // 'modelName',
      'componentName'
    );
  }

  prompting () {
    if (!this._canPrompt()) { return false; }
    const questions = this._getQuestions(
      'packageNameList',
      'packageNameIfManual',
      // 'modelNameList',
      // 'modelNameIfManual',
      'componentName',
      'componentType',
      'isRegisterComponent'
    );
    return this.prompt(questions)
    .then((answers) => {
      this.props = {
        packageName: this._finalize('packageName', answers),
        // modelName: this._finalize('modelName', answers),
        componentName: this._finalize('componentName', answers),
        componentFileName: this._finalize('componentFileName', answers),
        componentType: this._finalize('raw', 'componentType', answers),
        isRegister: this._finalize('raw', 'isRegister', answers),
      };
      this.props.componentPath = this._finalize('componentPath', answers);
    });
  }

  _writeComponent () {
    const templatePath = this.props.componentType === 'pure' ?
      this.templatePath('pureFunctionComponent.js') :
      this.templatePath('classComponent.js');
    this.fs.copyTpl(
      templatePath,
      this._getPath(
        { isAbsolute: true },
        'components',
        this.props.componentFileName
      ),
      this.props
    );
  }

  _updateComponentsIndex () {
    if (!this.props.isRegister) return;
    const componentsIndexPath = this._getPath(
      { isAbsolute: true },
      'componentsIndex'
    );
    const fileText = this.fs.read(componentsIndexPath);
    const fileWithImportText = ast.addImportStatement(
      fileText,
      `./${this.props.componentFileName}`
    );
    this.fs.write(
      componentsIndexPath,
      fileWithImportText
    );
  }

  writing () {
    if (!this._canWrite()) { return; }
    this._writeComponent();
    this._updateComponentsIndex();
  }

  end () {
    this._end();
  }
};

==> vulcanjs-cli-3.3.0.tgz: package/src/generator-vulcanjs/generators/component/index.js <==
const VulcanGenerator = require('../../lib/VulcanGenerator');
const ast = require('../../lib/ast');

module.exports = class extends VulcanGenerator {
  initializing () {
    this._assert('isVulcan');
    this._assert('hasNonZeroPackages');
  }

  _registerArguments () {
    this._registerOptions('packageName', 'componentName');
  }

  prompting () {
    if (!this._canPrompt()) {
      return false;
    }
    let questions = [];
    if (this._needArg('packageName')) {
      questions = [...questions, ...this._getQuestions('packageNameList')];
    }
    if (this._needArg('componentName')) {
      questions = [...questions, ...this._getQuestions('componentName')];
    }
    questions = [
      ...questions,
      ...this._getQuestions('componentType', 'isRegisterComponent'),
    ];
    return this.prompt(questions).then((answers) => {
      this.props = {
        packageName: this._finalize('packageName', answers),
        componentName: this._finalize('componentName', answers),
        componentFileName: this._finalize('componentFileName', answers),
        componentType: this._finalize('raw', 'componentType', answers),
        isRegister: this._finalize('raw', 'isRegister', answers),
      };
      this.props.componentPath = this._finalize('componentPath', answers);
    });
  }

  _writeComponent () {
    const templatePath =
      this.props.componentType === 'pure'
        ? this.templatePath('pureFunctionComponent.js')
        : this.templatePath('classComponent.js');
    this.fs.copyTpl(
      templatePath,
      this._getPath(
        { isAbsolute: true },
        'components',
        this.props.componentFileName
      ),
      this.props
    );
  }

  _updateComponentsIndex () {
    if (!this.props.isRegister) return;
    const componentsIndexPath = this._getPath(
      { isAbsolute: true },
      'componentsIndex'
    );
    const fileText = this.fs.read(componentsIndexPath);
    const fileWithImportText = ast.addImportStatement(
      fileText,
      `../components/${this.props.componentFileName}`
    );
    this.fs.write(componentsIndexPath, fileWithImportText);
  }

  writing () {
    if (!this._canWrite()) {
      return;
    }
    this._writeComponent();
    this._updateComponentsIndex();
  }

  end () {
    this._end();
  }
};
